RubinDirectoryCollection
========================

.. currentmodule:: toasty.collection

.. autoclass:: RubinDirectoryCollection
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~RubinDirectoryCollection.descriptions
      ~RubinDirectoryCollection.images

   .. rubric:: Methods Documentation

   .. automethod:: descriptions
   .. automethod:: images
